@@ -7,7 +7,8 @@
 ##parameters=category, isGlobalMap
 ##title=
 
-output="var icon;"
+newline="\n"
+output=""
 if(category.getCustomIcon() != None and category.getCustomIcon() != ""):                
     output+='icon = createIcon(\''+category.absolute_url()+'/CustomIcon'+'\');'
 else:
@@ -15,6 +16,17 @@ else:
         output+='icon = createIcon(\''+category.getCategoryIcon()+'\');'
     else:
         output+='icon = createIcon(\'ttgooglemap_marker.png\');'
+
+if(category.getClustererIcon() != None and category.getClustererIcon() != ""):
+    output+='clustererIcon = createClustererIcon(\''+category.absolute_url()+'/ClustererIcon'+'\');'
+else:
+    output+='clustererIcon = null;'
+
+output += newline
+
 if(isGlobalMap):
-    output+='gicons[\''+category.getUniqueId()+'\'] = icon;'
+    output+='gicons[\''+category.UID()+'\'] = icon;'
+    output+='clusterersIcon[\''+category.UID()+'\'] = clustererIcon;'
+    output += newline
+    
 return output
\ No newline at end of file
